Crate rustmeter_beacon

Crate rustmeter_beacon 

Macros

event_metric
Logs an event metric with a name and value via defmt.
monitor_scoped
The return value of the code block is passed through, allowing the macro to be used in assignments (see Example 2).

Functions

get_current_core_id
Returns the core ID of the currently executing core based on the target architecture. Supports various architectures including ESP32 (Xtensa and RISC-V), RP2040, and STM32 (single or H7 dual-core).

Attribute Macros

monitor_fn
Instruments a function to log execution for rustmeter