Module time_delta

Module time_delta 

Structs

TimeDelta

Statics

CORE_CLOCK_REFERENCED
Public static flag to check if local core clock (cpu performance counter) was referenced to systemtime. Can be reflagged to false via Host

Functions

get_system_time_us
get_tracing_raw_ticks
Low-level function to get the current tracing raw ticks. Implemented in the target crate. In tests this already should return the timedelta directly.
preinit_clock_reference
Low-level function to get the current tracing time in microseconds. Implemented in the target crate. In tests this already should return the timedelta directly. Low-level function to preinitialize the clock reference for the target core. Implemented in the target crate. Runs in critical section.