TimeDelta

Struct TimeDelta 

pub struct TimeDelta { /* private fields */ }

Implementations

Source

impl TimeDelta

pub fn from_now() -> TimeDelta

This has to be called inside a critical section

pub const fn is_extended(&self) -> bool

Returns true if the TimeDelta requires extended format (4 bytes), false if it can be represented in single format (2 bytes).

pub fn write_bytes(&self, writer: &mut BufferWriter)

Write the TimeDelta into the provided writer. It will use either 2 or 4 bytes depending on the size:

  • If the delta is less than 2^15, it will be written as a 2-byte value with the highest bit set to 0.
  • If the delta is 2^15 or more, it will be written as a 4-byte value with the highest bit set to 1. If the delta exceeds 2^31 - 1, it will be capped to that value.
pub fn write_bytes_mut(&self, writer: &mut [u8]) -> usize

pub fn read_bytes( reader: &mut BufferReader<'_>, ) -> Result<TimeDelta, ReadTracingError>

Reads a TimeDelta from the provided reader. Returns None if reading fails. It automatically detects whether the format is single (2 bytes) or extended (4 bytes) based on the highest bit. This method can only “fail” if there is not enough data in the reader.

pub fn delta(&self) -> u32

Returns the delta in microseconds