pub fn write_tracing_event(event: EventPayload)Expand description
Serializes and writes a tracing event with timestamp to the tracing channel
pub fn write_tracing_event(event: EventPayload)Serializes and writes a tracing event with timestamp to the tracing channel