Crate rustmeter_beacon
rustmeter_
beacon
0.1.0
All Items
Crate Items
Macros
Functions
Attribute Macros
Crate
rustmeter_
beacon
Macros

event_
metric
Logs an event metric with a name and value via defmt.
monitor_
scoped
The return value of the code block is passed through, allowing the macro to be used in assignments (see Example 2).
Functions

get_
current_
core_
id
Returns the core ID of the currently executing core based on the target architecture. Supports various architectures including ESP32 (Xtensa and RISC-V), RP2040, and STM32 (single or H7 dual-core).
Attribute Macros

monitor_
fn
Instruments a function to log execution for rustmeter