pub enum TypeDefinitionPayload {
EmbassyTaskCreated {
task_id: u32,
executor_id_long: u32,
executor_id_short: UInt<u8, 3>,
},
EmbassyTaskEnded {
task_id: u32,
executor_id_long: u32,
executor_id_short: UInt<u8, 3>,
},
FunctionMonitor {
monitor_id: u8,
fn_address: u32,
},
ScopeMonitor {
monitor_id: u8,
name: &'static str,
},
ValueMonitor {
value_id: u8,
name: &'static str,
},
GlobalClockConfiguration {
system_frequency_hz: u32,
tick_divider: u16,
},
CoreClockReference {
core_id: u8,
systimer_us: u64,
cpu_ticks: u32,
},
}Expand description
Type Definition Event Payloads (as tagged enum)
Variants
EmbassyTaskCreated
New Embassy Task created. TaskID is the full task ID used in TaskReady events. (Can be compressed on host side to gather shorter taskid) ExecutorIDLong is the full executor ID used to identify the executor instance. ExecutorIDShort is the short executor ID used in events to identify the executor instance
EmbassyTaskEnded
Embassy Task ended TaskID is the full task ID used in TaskReady events. (Can be compressed on host side to gather shorter taskid) ExecutorIDLong is the full executor ID used to identify the executor instance. ExecutorIDShort is the short executor ID used in events to identify the executor instance This event indicates that the task will not be scheduled again.
FunctionMonitor
New Function Monitor defined MonitorID identifies the monitor instance in future events. FnAddress is the function address being monitored.
ScopeMonitor
New Scope Monitor defined MonitorID identifies the monitor instance in future events. Name is a null-terminated string representing the name of the scope (max. 20 Characters).
ValueMonitor
New Value Monitor defined ValueID identifies the monitor instance in future events. Name is a null-terminated string representing the name of the value (max. 20 Characters).
GlobalClockConfiguration
CoreClockReference
Core Clock Reference Event. Syncing CPU ticks to system timer time and core ID. Allows to calibrate different cores against each other and the system time. This also helps to match cpu ticks with Log Lines
Implementations